@@ -6,7 +6,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '2.01';
+our $VERSION = '2.03';
 
 my %TAG_TEMPLATE;
 $TAG_TEMPLATE{css} = [qw(link rel stylesheet href)];
@@ -75,7 +75,12 @@ sub process {
   return $self->_process($topic => $assets);
 }
 
-sub processed { $_[0]->{by_topic}{$_[1]} }
+sub processed {
+  my ($self, $topic) = @_;
+  $self->_process($topic => $self->{input}{$topic})
+    unless $self->{by_topic}{$topic};    # Ensure asset is processed
+  return $self->{by_topic}{$topic};
+}
 
 sub register {
   my ($self, $app, $config) = @_;
@@ -252,7 +257,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-2.01
+2.03
 
 =head1 SYNOPSIS
 
